<?php
header("Access-Control-Allow-Origin: *");
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: GET");
header("Access-Control-Max-Age: 3600");
header("Access-Control-Allow-Headers: Content-Type, Access-Control-Allow-Headers, Authorization, X-Requested-With");

// Connect to the database
include '../config/database2.php';

  // Validate the API key
$expected_api_key = "8L14irhDOhBUffrmiv2kqUSoSpeIK9D7JYDmsPVS9-M";

$received_api_key = isset($_SERVER['HTTP_AUTH']) ? trim($_SERVER['HTTP_AUTH']) : '';


if ($received_api_key !== $expected_api_key) {
    $response = [
        'success' => false,
        'message' => "Invalid API Key."
    ];
    echo json_encode($response);
    exit; // Terminate the script if the API key is invalid
}

// Check connection
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Get the branch ID
$branchId = $_GET['branchid'];
$departmentId = $_GET['departmentId'];

// Pagination parameters
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1; // Get the requested page, default is 1
$itemsPerPage = 9;
$offset = ($page - 1) * $itemsPerPage;

// Query to get total count of items

$countQuery = "SELECT COUNT(*) AS total 
              FROM inventorylocationitems AS ili
              INNER JOIN productimages AS pi ON ili.itemID = pi.itemID
              INNER JOIN item ON ili.itemID = item.id
              WHERE ili.inventoryLocation = ? 
              AND item.departmentID = ? 
              AND ili.quantity > 2 
              AND pi.pic1 IS NOT NULL";
$stmtCount = $conn->prepare($countQuery);
$stmtCount->bind_param('ii', $branchId, $departmentId);
$stmtCount->execute();
$totalCount = $stmtCount->get_result()->fetch_assoc()['total'];


// Calculate total pages
$totalPages = ceil($totalCount / $itemsPerPage);

// Main query with pagination
$sql = "SELECT 
    item.id AS itemID, 
    item.description, item.is_serial,
    item.longdescription, 
    item.departmentID, 
    department.Name AS department_name, 
    inventorylocationitems.price, 
    inventorylocationitems.cost, 
    inventorylocationitems.quantity, 
    CONCAT('https://admin.kassmatt.com/dist/img/items/',item.ID, '/', productimages.pic1) AS imageUrl
    
FROM 
    inventorylocationitems
INNER JOIN 
    item ON inventorylocationitems.itemID = item.id
LEFT JOIN 
    productimages ON inventorylocationitems.itemID = productimages.itemID
LEFT JOIN 
    department ON item.departmentID = department.ID
WHERE 
    inventorylocationitems.inventoryLocation = ? 
    AND item.departmentID = ?
    AND inventorylocationitems.quantity > 2 
    AND productimages.pic1 IS NOT NULL 
LIMIT ?, ?";

$stmt = $conn->prepare($sql);
$stmt->bind_param('iiii', $branchId,$departmentId, $offset, $itemsPerPage);
$stmt->execute();
$items = $stmt->get_result()->fetch_all(MYSQLI_ASSOC);

// Prepare the response data
$response = [
    'total_pages' => $totalPages,
    'current_page' => $page,
    'items' => $items
];

// Return the API response
echo json_encode($response);

$conn->close();



?>
