<?php
header("Access-Control-Allow-Origin: *");
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: POST");
header("Access-Control-Max-Age: 3600");
header("Access-Control-Allow-Headers: Content-Type, Access-Control-Allow-Headers, Authorization, X-Requested-With");

// Validate the API key
$expected_api_key = "8L14irhDOhBUffrmiv2kqUSoSpeIK9D7JYDmsPVS9-M";

$received_api_key = isset($_SERVER['HTTP_AUTH']) ? trim($_SERVER['HTTP_AUTH']) : '';

if ($received_api_key !== $expected_api_key) {
    $response = [
        'success' => false,
        'message' => "Invalid API Key."
    ];
    echo json_encode($response);
    exit; // Terminate the script if the API key is invalid
}

// Get the JSON data from the request body
$json = file_get_contents('php://input');
$data = json_decode($json, true);

// Extract the data fields
$fullname = $data['fullname'];
$email = $data['email'];
$mobile = $data['cell'];
$password = $data['password'];

if (empty($mobile)) {
    $response = [
        'success' => false,
        'message' => 'Mobile is required for registration.'
    ];
    echo json_encode($response);
    exit; // Terminate the script if the mobile is not provided
}

// Hash the password using MD5
$hashedPassword = md5($password);

// Connect to the database
include '../config/database3.php';

// Check connection
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Begin a transaction
$conn->begin_transaction();

// Insert the new user into the database
$stmt = $conn->prepare("INSERT INTO members (Fullname, EmailAdd, Mobile, TelNo, Password) VALUES (?, ?, ?, ?, ?)");
$stmt->bind_param("sssss", $fullname, $email, $mobile, $mobile, $hashedPassword);
$stmt->execute();

// Get the last inserted ID
$lastInsertedID = mysqli_insert_id($conn);


// Add a prefix starting with '00' and 1 random number (1 to 9)
$prefix = '00' . rand(1, 9);

// Calculate the number of zeros needed to make the total length 11
$zerosCount = max(0, 11 - strlen($prefix) - strlen($lastInsertedID));

// Form the Loyaltyno by combining the prefix, zeros, and the last inserted ID
$newLoyaltyno = $prefix . str_repeat('0', $zerosCount) . $lastInsertedID;


// Update the Loyaltyno for the inserted member
$updateStmt = $conn->prepare("UPDATE members SET Loyaltyno = ? WHERE ID = ?");
$updateStmt->bind_param("si", $newLoyaltyno, $lastInsertedID);
$updateStmt->execute();

// Commit the transaction
$conn->commit();

// Return a success response
$response = [
    'success' => true,
    'message' => 'Registration successful.',
    'loyaltyno' => $newLoyaltyno
];

echo json_encode($response);

// Close the connection
$conn->close();
?>
